layout

package
v0.1.38 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DashboardLayout

type DashboardLayout struct {
	Width   int
	Height  int
	Repo    int
	PR      int
	Preview int
}

func Calculate

func Calculate(width, height int) DashboardLayout

Calculate derives panel widths for the dashboard body. Widths returned are content widths (excluding borders and gaps).

type LayoutState

type LayoutState struct {
	Width   int
	Height  int
	Current DashboardLayout
}

func NewLayoutState

func NewLayoutState(width, height int) LayoutState

NewLayoutState builds a layout state for the provided terminal size.

func (LayoutState) SetSize

func (s LayoutState) SetSize(width, height int) LayoutState

SetSize recalculates the dashboard layout for a terminal size.

func (LayoutState) Update

func (s LayoutState) Update(msg tea.Msg) LayoutState

Jump to