Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DashboardLayout ¶
func Calculate ¶
func Calculate(width, height int) DashboardLayout
Calculate derives panel widths for the dashboard body. Widths returned are content widths (excluding borders and gaps).
type LayoutState ¶
type LayoutState struct {
Width int
Height int
Current DashboardLayout
}
func NewLayoutState ¶
func NewLayoutState(width, height int) LayoutState
NewLayoutState builds a layout state for the provided terminal size.
func (LayoutState) SetSize ¶
func (s LayoutState) SetSize(width, height int) LayoutState
SetSize recalculates the dashboard layout for a terminal size.
func (LayoutState) Update ¶
func (s LayoutState) Update(msg tea.Msg) LayoutState
Click to show internal directories.
Click to hide internal directories.